---
title: <span class="badge builder"></span> FiltersSettings
---
# <span class="badge builder"></span> FiltersSettings

## Constructor

```python
FiltersSettings()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> elasticsearch.FiltersSettings
```

### <span class="badge object-method"></span> filters

```python
def filters(filters: list[cogbuilder.Builder[elasticsearch.Filter]]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [FiltersSettings](./object-FiltersSettings.md)
